import { AfterViewInit, ChangeDetectorRef, DoCheck, ElementRef, EventEmitter, NgZone, OnDestroy, OnInit, QueryList } from '@angular/core';
import { ControlValueAccessor, FormControl } from '@angular/forms';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/distinctUntilChanged';
import { ValidateEssentialSelectFn } from './essential-select.validator';
import { EssentialSelectOptions } from './essential-select.printable';
import { EssentialsSelectFilter } from './filters/filter.models';
import { WrapperContent } from './essential-select.settings';
import 'rxjs/add/observable/of';
import 'rxjs/add/operator/delay';
import { EssentialSelectModuleConfig } from './essential-select-config';
export declare class EssentialSelectComponent implements DoCheck, OnInit, AfterViewInit, OnDestroy, ControlValueAccessor {
    private _changeDetectionRef;
    private ngZone;
    private essentialSelectModuleConfig;
    /**
     * analogue of [(ngModel)]; selected value of
     */
    value: any;
    /**
     * subscribe to value changes
     * @type {EventEmitter<any>}
     */
    valueChange: EventEmitter<any>;
    /**
     * array of possible options that user can select
     */
    options: any[];
    /**
     * limit to show options in list
     * @type {number}
     */
    optionsDisplayLimit: number;
    /**
     *  If you pass some complex objects (not number/string) - you must pass ID of property that every "options" object contains
     */
    fieldValue: string;
    /**
     * Name of property to show in "options" object
     */
    fieldName: string;
    /**
     * false - if we want "value" to contain only some ID instead of all object from global; true if we want to store the whole object
     * @type {boolean}
     */
    bindObject: boolean;
    /**
     * Is it a required field for validation
     * @type {boolean}
     */
    required: boolean;
    /**
     * Enable auto-complete option
     * @type {boolean}
     */
    hasSearchInput: boolean;
    searchInputType: string;
    /**
     * Handle wen user search something; only valid if you have hasSearchInput=true
     * @type {EventEmitter<string>}
     */
    searchChange: EventEmitter<string>;
    /**
     * Optional. Message when component is invalid
     */
    invalidText: string;
    selectAllText: string;
    unselectAllText: string;
    notSelectedText: string;
    placeholder: string;
    /**
     * Hide 'Not selected' option (equals to null)
     */
    disableUnselected: boolean;
    /**
     * Custom validation function
     */
    validateFn: ValidateEssentialSelectFn;
    /**
     * Main object for dynamically customization print and select behaviour of select
     */
    selectPrintable: EssentialSelectOptions<any>;
    /**
     * Customize behaviour of filtering options. By default use TextToShowEssentialFilter.
     * @type {TextToShowEssentialFilter}
     */
    essentialsSelectFilter: EssentialsSelectFilter;
    /**
     * Is multiselect mode
     */
    useMultiSelect: boolean;
    /**
     * Maximum elements to inline in input
     * @type {number}
     */
    multiSelectMaximumInlinedElements: number;
    /**
     * Is select disabled
     */
    disabled: boolean;
    /**
     * Control dropdown strategy
     * @type {WrapperContent.MATCH_FORM}
     */
    wrapType: WrapperContent;
    wrapperClasses: string[];
    /**
     * angular forms automatically change null/undefined string to empty ""
     * that's a workaround. If you need empty string as a value - disable that
     * @type {boolean}
     */
    treatEmptyStringAsNull: boolean;
    private prevValueOutside;
    private ourChange;
    private _userSelectedTimes;
    private _limit;
    private _internalValue;
    private container;
    selectDropdown: QueryList<ElementRef>;
    private containerLength;
    private contentLengthInner;
    private inputSelectPlaceholder;
    private ngForm;
    private notSearchContaner;
    _userHasInputTextToSearchBeforeSelect: boolean;
    _isValidated: boolean;
    _showOpenCloseIcon: boolean;
    _pipeNumber: number;
    _isOpen: boolean;
    _searchBoxValue: any;
    private _windowChangeListener;
    /**
     * Integration API - get current number availbale letters in placeholder
     * @return {number}
     */
    readonly limit: number;
    /**
     * Primary for integration purposes
     * @returns {any}
     */
    readonly internalValue: any;
    /**
     *
     * @returns {boolean} true if user selected some value after components initialized
     */
    isDirty(): boolean;
    propagateChange: (_: any) => void;
    private onTouched;
    registerOnChange(fn: any): void;
    writeValue(obj: any): void;
    registerOnTouched(fn: any): void;
    validate(c: FormControl): boolean;
    setDisabledState(isDisabled: boolean): void;
    constructor(_changeDetectionRef: ChangeDetectorRef, ngZone: NgZone, essentialSelectModuleConfig: EssentialSelectModuleConfig);
    /**
     *
     * @returns {ElementRef} html container of element
     */
    getElementRef(): ElementRef;
    setOpen(newState: boolean): void;
    _getDropdownWidth(): string;
    changeOpen(): void;
    isOpenEditable(): boolean;
    onSearchInputChange($event: any): void;
    valid(): boolean;
    markTouched(): void;
    /**
     *
     * @returns {boolean} true of form was validated or user touched it
     */
    isTouched(): boolean;
    private getLang();
    private getLangTransSelectLang();
    ngOnInit(): void;
    /**
     * Multiselect only; Select all elements
     */
    selectAll(): void;
    /**
     * Multiselect only; Unselect all elements
     */
    unselectAll(): void;
    ngAfterViewInit(): void;
    private _doChangeDropdownWidth(x);
    private haveFieldValue();
    private getSimpleTextPrintable(item);
    haveNotValue(value: any): boolean;
    enabledRowClasses(): boolean;
    printRowClasses(item: any): string;
    getCssClasses(item: any): string;
    /**
     * Change detection from outside
     * We need to check to first bind object or detect changes with was done outside the component
     */
    ngDoCheck(): void;
    private doFinalOusideChanges();
    printValue(): string;
    isSelected(val: any): boolean;
    printItemValueAdditionalNotes(item: any): string[];
    printItemValue(item: any): string;
    onUserOptionSelected(option: any): boolean;
    /**
     * @param option
     * @returns {boolean} - true if can select option
     */
    onOptionSelected(option: any): boolean;
    private safeAccessInternavlValue();
    private handleNewInternalMultibindingValue();
    private checkCanBeDeSelected(form);
    private checkCanBeSelected(form);
    /** Select some option
     * @param form selected value
     */
    private select(form);
    /**
     * Refresh search input after model changes
     */
    private checkAndUpdateSearchInput();
    joinDefaultMultiSelect(): string;
    private getStringVisualLengthInPx(stringTest);
    findPlaceholderLength(stringTest: string): void;
    ngOnDestroy(): void;
    clickHandler(event: any): void;
}
